# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: mobile
using AWS.Compat
using AWS.UUIDs

"""
    CreateProject()

 Creates an AWS Mobile Hub project. 

# Optional Parameters
- `contents`:  ZIP or YAML file which contains configuration settings to be used when creating the project. This may be the contents of the file downloaded from the URL provided in an export project operation. 
- `name`:  Name of the project. 
- `region`:  Default region where project resources should be created. 
- `snapshotId`:  Unique identifier for an exported snapshot of project configuration. This snapshot identifier is included in the share URL when a project is exported. 
"""
create_project(; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/projects"; aws_config=aws_config)
create_project(args::AbstractDict{String, Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/projects", args; aws_config=aws_config)

"""
    DeleteProject()

 Delets a project in AWS Mobile Hub. 

# Required Parameters
- `projectId`:  Unique project identifier. 

"""
delete_project(projectId; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("DELETE", "/projects/$(projectId)"; aws_config=aws_config)
delete_project(projectId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("DELETE", "/projects/$(projectId)", args; aws_config=aws_config)

"""
    DescribeBundle()

 Get the bundle details for the requested bundle id. 

# Required Parameters
- `bundleId`:  Unique bundle identifier. 

"""
describe_bundle(bundleId; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/bundles/$(bundleId)"; aws_config=aws_config)
describe_bundle(bundleId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/bundles/$(bundleId)", args; aws_config=aws_config)

"""
    DescribeProject()

 Gets details about a project in AWS Mobile Hub. 

# Required Parameters
- `projectId`:  Unique project identifier. 

# Optional Parameters
- `syncFromResources`:  If set to true, causes AWS Mobile Hub to synchronize information from other services, e.g., update state of AWS CloudFormation stacks in the AWS Mobile Hub project. 
"""
describe_project(projectId; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/project", Dict{String, Any}("projectId"=>projectId); aws_config=aws_config)
describe_project(projectId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/project", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("projectId"=>projectId), args)); aws_config=aws_config)

"""
    ExportBundle()

 Generates customized software development kit (SDK) and or tool packages used to integrate mobile web or mobile app clients with backend AWS resources. 

# Required Parameters
- `bundleId`:  Unique bundle identifier. 

# Optional Parameters
- `platform`:  Developer desktop or target application platform. 
- `projectId`:  Unique project identifier. 
"""
export_bundle(bundleId; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/bundles/$(bundleId)"; aws_config=aws_config)
export_bundle(bundleId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/bundles/$(bundleId)", args; aws_config=aws_config)

"""
    ExportProject()

 Exports project configuration to a snapshot which can be downloaded and shared. Note that mobile app push credentials are encrypted in exported projects, so they can only be shared successfully within the same AWS account. 

# Required Parameters
- `projectId`:  Unique project identifier. 

"""
export_project(projectId; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/exports/$(projectId)"; aws_config=aws_config)
export_project(projectId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/exports/$(projectId)", args; aws_config=aws_config)

"""
    ListBundles()

 List all available bundles. 

# Optional Parameters
- `maxResults`:  Maximum number of records to list in a single response. 
- `nextToken`:  Pagination token. Set to null to start listing bundles from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more bundles. 
"""
list_bundles(; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/bundles"; aws_config=aws_config)
list_bundles(args::AbstractDict{String, Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/bundles", args; aws_config=aws_config)

"""
    ListProjects()

 Lists projects in AWS Mobile Hub. 

# Optional Parameters
- `maxResults`:  Maximum number of records to list in a single response. 
- `nextToken`:  Pagination token. Set to null to start listing projects from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more projects. 
"""
list_projects(; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/projects"; aws_config=aws_config)
list_projects(args::AbstractDict{String, Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("GET", "/projects", args; aws_config=aws_config)

"""
    UpdateProject()

 Update an existing project. 

# Required Parameters
- `projectId`:  Unique project identifier. 

# Optional Parameters
- `contents`:  ZIP or YAML file which contains project configuration to be updated. This should be the contents of the file downloaded from the URL provided in an export project operation. 
"""
update_project(projectId; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/update", Dict{String, Any}("projectId"=>projectId); aws_config=aws_config)
update_project(projectId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mobile("POST", "/update", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("projectId"=>projectId), args)); aws_config=aws_config)
