# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: quicksight
using AWS.Compat
using AWS.UUIDs

"""
    CancelIngestion()

Cancels an ongoing ingestion of data into SPICE.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID of the dataset used in the ingestion.
- `IngestionId`: An ID for the ingestion.

"""
cancel_ingestion(AwsAccountId, DataSetId, IngestionId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions/$(IngestionId)"; aws_config=aws_config)
cancel_ingestion(AwsAccountId, DataSetId, IngestionId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions/$(IngestionId)", args; aws_config=aws_config)

"""
    CreateAccountCustomization()

Creates Amazon QuickSight customizations the current AWS Region. Currently, you can add a custom default theme by using the CreateAccountCustomization or UpdateAccountCustomization API operation. To further customize QuickSight by removing QuickSight sample assets and videos for all new users, see Customizing QuickSight in the Amazon QuickSight User Guide.  You can create customizations for your AWS account or, if you specify a namespace, for a QuickSight namespace instead. Customizations that apply to a namespace always override customizations that apply to an AWS account. To find out which customizations apply, use the DescribeAccountCustomization API operation. Before you use the CreateAccountCustomization API operation to add a theme as the namespace default, make sure that you first share the theme with the namespace. If you don't share it with the namespace, the theme isn't visible to your users even if you make it the default theme. To check if the theme is shared, view the current permissions by using the  DescribeThemePermissions  API operation. To share the theme, grant permissions by using the  UpdateThemePermissions  API operation. 

# Required Parameters
- `AccountCustomization`: The QuickSight customizations you're adding in the current AWS Region. You can add these to an AWS account and a QuickSight namespace.  For example, you can add a default theme by setting AccountCustomization to the midnight theme: \"AccountCustomization\": { \"DefaultTheme\": \"arn:aws:quicksight::aws:theme/MIDNIGHT\" }. Or, you can add a custom theme by specifying \"AccountCustomization\": { \"DefaultTheme\": \"arn:aws:quicksight:us-west-2:111122223333:theme/bdb844d0-0fe9-4d9d-b520-0fe602d93639\" }. 
- `AwsAccountId`: The ID for the AWS account that you want to customize QuickSight for.

# Optional Parameters
- `Tags`: A list of the tags that you want to attach to this resource.
- `namespace`: The QuickSight namespace that you want to add customizations to.
"""
create_account_customization(AccountCustomization, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/customizations", Dict{String, Any}("AccountCustomization"=>AccountCustomization); aws_config=aws_config)
create_account_customization(AccountCustomization, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/customizations", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountCustomization"=>AccountCustomization), args)); aws_config=aws_config)

"""
    CreateAnalysis()

Creates an analysis in Amazon QuickSight.

# Required Parameters
- `AnalysisId`: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
- `AwsAccountId`: The ID of the AWS account where you are creating an analysis.
- `Name`: A descriptive name for the analysis that you're creating. This name displays for the analysis in the QuickSight console. 
- `SourceEntity`: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets.

# Optional Parameters
- `Parameters`: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values. 
- `Permissions`: A structure that describes the principals and the resource-level permissions on an analysis. You can use the Permissions structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).  To specify no permissions, omit Permissions.
- `Tags`: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
- `ThemeArn`: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the QuickSight console, make sure that you have access to it.
"""
create_analysis(AnalysisId, AwsAccountId, Name, SourceEntity; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)", Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity); aws_config=aws_config)
create_analysis(AnalysisId, AwsAccountId, Name, SourceEntity, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity), args)); aws_config=aws_config)

"""
    CreateDashboard()

Creates a dashboard from a template. To first create a template, see the  CreateTemplate  API operation. A dashboard is an entity in QuickSight that identifies QuickSight reports, created from analyses. You can share QuickSight dashboards. With the right permissions, you can create scheduled email reports from them. If you have the correct permissions, you can create a dashboard from a template that exists in a different AWS account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account where you want to create the dashboard.
- `DashboardId`: The ID for the dashboard, also added to the IAM policy.
- `Name`: The display name of the dashboard.
- `SourceEntity`: The entity that you are using as a source when you create the dashboard. In SourceEntity, you specify the type of object you're using as source. You can only create a dashboard from a template, so you use a SourceTemplate entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the CreateTemplate API operation. For SourceTemplate, specify the Amazon Resource Name (ARN) of the source template. The SourceTemplateARN can contain any AWS Account and any QuickSight-supported AWS Region.  Use the DataSetReferences entity within SourceTemplate to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. 

# Optional Parameters
- `DashboardPublishOptions`: Options for publishing the dashboard when you create it:    AvailabilityStatus for AdHocFilteringOption - This status can be either ENABLED or DISABLED. When this is set to DISABLED, QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ENABLED by default.     AvailabilityStatus for ExportToCSVOption - This status can be either ENABLED or DISABLED. The visual option to export data to .CSV format isn't enabled when this is set to DISABLED. This option is ENABLED by default.     VisibilityState for SheetControlsOption - This visibility state can be either COLLAPSED or EXPANDED. This option is COLLAPSED by default.   
- `Parameters`: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values. 
- `Permissions`: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.  To specify no permissions, omit the permissions list.
- `Tags`: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
- `ThemeArn`: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
- `VersionDescription`: A description for the first version of the dashboard being created.
"""
create_dashboard(AwsAccountId, DashboardId, Name, SourceEntity; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)", Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity); aws_config=aws_config)
create_dashboard(AwsAccountId, DashboardId, Name, SourceEntity, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity), args)); aws_config=aws_config)

"""
    CreateDataSet()

Creates a dataset.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
- `ImportMode`: Indicates whether you want to import the data into SPICE.
- `Name`: The display name for the dataset.
- `PhysicalTableMap`: Declares the physical tables that are available in the underlying data sources.

# Optional Parameters
- `ColumnGroups`: Groupings of columns that work together in certain QuickSight features. Currently, only geospatial hierarchy is supported.
- `ColumnLevelPermissionRules`: A set of one or more definitions of a  ColumnLevelPermissionRule .
- `LogicalTableMap`: Configures the combination and transformation of the data from the physical tables.
- `Permissions`: A list of resource permissions on the dataset.
- `RowLevelPermissionDataSet`: The row-level security configuration for the data that you want to create.
- `Tags`: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
"""
create_data_set(AwsAccountId, DataSetId, ImportMode, Name, PhysicalTableMap; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sets", Dict{String, Any}("DataSetId"=>DataSetId, "ImportMode"=>ImportMode, "Name"=>Name, "PhysicalTableMap"=>PhysicalTableMap); aws_config=aws_config)
create_data_set(AwsAccountId, DataSetId, ImportMode, Name, PhysicalTableMap, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sets", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("DataSetId"=>DataSetId, "ImportMode"=>ImportMode, "Name"=>Name, "PhysicalTableMap"=>PhysicalTableMap), args)); aws_config=aws_config)

"""
    CreateDataSource()

Creates a data source.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSourceId`: An ID for the data source. This ID is unique per AWS Region for each AWS account. 
- `Name`: A display name for the data source.
- `Type`: The type of the data source. Currently, the supported types for this operation are: ATHENA, AURORA, AURORA_POSTGRESQL, MARIADB, MYSQL, POSTGRESQL, PRESTO, REDSHIFT, S3, SNOWFLAKE, SPARK, SQLSERVER, TERADATA. Use ListDataSources to return a list of all data sources.

# Optional Parameters
- `Credentials`: The credentials QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
- `DataSourceParameters`: The parameters that QuickSight uses to connect to your underlying source.
- `Permissions`: A list of resource permissions on the data source.
- `SslProperties`: Secure Socket Layer (SSL) properties that apply when QuickSight connects to your underlying source.
- `Tags`: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
- `VpcConnectionProperties`: Use this parameter only when you want QuickSight to use a VPC connection when connecting to your underlying source.
"""
create_data_source(AwsAccountId, DataSourceId, Name, Type; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sources", Dict{String, Any}("DataSourceId"=>DataSourceId, "Name"=>Name, "Type"=>Type); aws_config=aws_config)
create_data_source(AwsAccountId, DataSourceId, Name, Type, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sources", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("DataSourceId"=>DataSourceId, "Name"=>Name, "Type"=>Type), args)); aws_config=aws_config)

"""
    CreateGroup()

Creates an Amazon QuickSight group. The permissions resource is arn:aws:quicksight:us-east-1:&lt;relevant-aws-account-id&gt;:group/default/&lt;group-name&gt; . The response is a group object.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: A name for the group that you want to create.
- `Namespace`: The namespace. Currently, you should set this to default.

# Optional Parameters
- `Description`: A description for the group that you want to create.
"""
create_group(AwsAccountId, GroupName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups", Dict{String, Any}("GroupName"=>GroupName); aws_config=aws_config)
create_group(AwsAccountId, GroupName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("GroupName"=>GroupName), args)); aws_config=aws_config)

"""
    CreateGroupMembership()

Adds an Amazon QuickSight user to an Amazon QuickSight group. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: The name of the group that you want to add the user to.
- `MemberName`: The name of the user that you want to add to the group membership.
- `Namespace`: The namespace. Currently, you should set this to default.

"""
create_group_membership(AwsAccountId, GroupName, MemberName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)/members/$(MemberName)"; aws_config=aws_config)
create_group_membership(AwsAccountId, GroupName, MemberName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)/members/$(MemberName)", args; aws_config=aws_config)

"""
    CreateIAMPolicyAssignment()

Creates an assignment with one specified IAM policy, identified by its Amazon Resource Name (ARN). This policy assignment is attached to the specified groups or users of Amazon QuickSight. Assignment names are unique per AWS account. To avoid overwriting rules in other namespaces, use assignment names that are unique.

# Required Parameters
- `AssignmentName`: The name of the assignment, also called a rule. It must be unique within an AWS account.
- `AssignmentStatus`: The status of the assignment. Possible values are as follows:    ENABLED - Anything specified in this assignment is used when creating the data source.    DISABLED - This assignment isn't used when creating the data source.    DRAFT - This assignment is an unfinished draft and isn't used when creating the data source.  
- `AwsAccountId`: The ID of the AWS account where you want to assign an IAM policy to QuickSight users or groups.
- `Namespace`: The namespace that contains the assignment.

# Optional Parameters
- `Identities`: The QuickSight users, groups, or both that you want to assign the policy to.
- `PolicyArn`: The ARN for the IAM policy to apply to the QuickSight users and groups specified in this assignment.
"""
create_iampolicy_assignment(AssignmentName, AssignmentStatus, AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments/", Dict{String, Any}("AssignmentName"=>AssignmentName, "AssignmentStatus"=>AssignmentStatus); aws_config=aws_config)
create_iampolicy_assignment(AssignmentName, AssignmentStatus, AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments/", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AssignmentName"=>AssignmentName, "AssignmentStatus"=>AssignmentStatus), args)); aws_config=aws_config)

"""
    CreateIngestion()

Creates and starts a new SPICE ingestion on a dataset Any ingestions operating on tagged datasets inherit the same tags automatically for use in access control. For an example, see How do I create an IAM policy to control access to Amazon EC2 resources using tags? in the AWS Knowledge Center. Tags are visible on the tagged dataset, but not on the ingestion resource.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID of the dataset used in the ingestion.
- `IngestionId`: An ID for the ingestion.

"""
create_ingestion(AwsAccountId, DataSetId, IngestionId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions/$(IngestionId)"; aws_config=aws_config)
create_ingestion(AwsAccountId, DataSetId, IngestionId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions/$(IngestionId)", args; aws_config=aws_config)

"""
    CreateNamespace()

(Enterprise edition only) Creates a new namespace for you to use with Amazon QuickSight. A namespace allows you to isolate the QuickSight users and groups that are registered for that namespace. Users that access the namespace can share assets only with other users or groups in the same namespace. They can't see users and groups in other namespaces. You can create a namespace after your AWS account is subscribed to QuickSight. The namespace must be unique within the AWS account. By default, there is a limit of 100 namespaces per AWS account. To increase your limit, create a ticket with AWS Support. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that you want to create the QuickSight namespace in.
- `IdentityStore`: Specifies the type of your user identity directory. Currently, this supports users with an identity type of QUICKSIGHT.
- `Namespace`: The name that you want to use to describe the new namespace.

# Optional Parameters
- `Tags`: The tags that you want to associate with the namespace that you're creating.
"""
create_namespace(AwsAccountId, IdentityStore, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)", Dict{String, Any}("IdentityStore"=>IdentityStore, "Namespace"=>Namespace); aws_config=aws_config)
create_namespace(AwsAccountId, IdentityStore, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("IdentityStore"=>IdentityStore, "Namespace"=>Namespace), args)); aws_config=aws_config)

"""
    CreateTemplate()

Creates a template from an existing QuickSight analysis or template. You can use the resulting template to create a dashboard. A template is an entity in QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `SourceEntity`: The entity that you are using as a source when you create the template. In SourceEntity, you specify the type of object you're using as source: SourceTemplate for a template or SourceAnalysis for an analysis. Both of these require an Amazon Resource Name (ARN). For SourceTemplate, specify the ARN of the source template. For SourceAnalysis, specify the ARN of the source analysis. The SourceTemplate ARN can contain any AWS Account and any QuickSight-supported AWS Region.  Use the DataSetReferences entity within SourceTemplate or SourceAnalysis to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. 
- `TemplateId`: An ID for the template that you want to create. This template is unique per AWS Region in each AWS account.

# Optional Parameters
- `Name`: A display name for the template.
- `Permissions`: A list of resource permissions to be set on the template. 
- `Tags`: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
- `VersionDescription`: A description of the current template version being created. This API operation creates the first version of the template. Every time UpdateTemplate is called, a new version is created. Each version of the template maintains a description of the version in the VersionDescription field.
"""
create_template(AwsAccountId, SourceEntity, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/templates/$(TemplateId)", Dict{String, Any}("SourceEntity"=>SourceEntity); aws_config=aws_config)
create_template(AwsAccountId, SourceEntity, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/templates/$(TemplateId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("SourceEntity"=>SourceEntity), args)); aws_config=aws_config)

"""
    CreateTemplateAlias()

Creates a template alias for a template.

# Required Parameters
- `AliasName`: The name that you want to give to the template alias that you're creating. Don't start the alias name with the  character. Alias names that start with  are reserved by QuickSight. 
- `AwsAccountId`: The ID of the AWS account that contains the template that you creating an alias for.
- `TemplateId`: An ID for the template.
- `TemplateVersionNumber`: The version number of the template.

"""
create_template_alias(AliasName, AwsAccountId, TemplateId, TemplateVersionNumber; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)", Dict{String, Any}("TemplateVersionNumber"=>TemplateVersionNumber); aws_config=aws_config)
create_template_alias(AliasName, AwsAccountId, TemplateId, TemplateVersionNumber, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("TemplateVersionNumber"=>TemplateVersionNumber), args)); aws_config=aws_config)

"""
    CreateTheme()

Creates a theme. A theme is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see Using Themes in Amazon QuickSight in the Amazon QuickSight User Guide.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account where you want to store the new theme. 
- `BaseThemeId`: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ListThemes or choose Themes from within a QuickSight analysis. 
- `Configuration`: The theme configuration, which contains the theme display properties.
- `Name`: A display name for the theme.
- `ThemeId`: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.

# Optional Parameters
- `Permissions`: A valid grouping of resource permissions to apply to the new theme. 
- `Tags`: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
- `VersionDescription`: A description of the first version of the theme that you're creating. Every time UpdateTheme is called, a new version is created. Each version of the theme has a description of the version in the VersionDescription field.
"""
create_theme(AwsAccountId, BaseThemeId, Configuration, Name, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/themes/$(ThemeId)", Dict{String, Any}("BaseThemeId"=>BaseThemeId, "Configuration"=>Configuration, "Name"=>Name); aws_config=aws_config)
create_theme(AwsAccountId, BaseThemeId, Configuration, Name, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/themes/$(ThemeId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("BaseThemeId"=>BaseThemeId, "Configuration"=>Configuration, "Name"=>Name), args)); aws_config=aws_config)

"""
    CreateThemeAlias()

Creates a theme alias for a theme.

# Required Parameters
- `AliasName`: The name that you want to give to the theme alias that you are creating. The alias name can't begin with a . Alias names that start with  are reserved by Amazon QuickSight. 
- `AwsAccountId`: The ID of the AWS account that contains the theme for the new theme alias.
- `ThemeId`: An ID for the theme alias.
- `ThemeVersionNumber`: The version number of the theme.

"""
create_theme_alias(AliasName, AwsAccountId, ThemeId, ThemeVersionNumber; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)", Dict{String, Any}("ThemeVersionNumber"=>ThemeVersionNumber); aws_config=aws_config)
create_theme_alias(AliasName, AwsAccountId, ThemeId, ThemeVersionNumber, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ThemeVersionNumber"=>ThemeVersionNumber), args)); aws_config=aws_config)

"""
    DeleteAccountCustomization()

Deletes all Amazon QuickSight customizations in this AWS Region for the specified AWS account and QuickSight namespace.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that you want to delete QuickSight customizations from in this AWS Region.

# Optional Parameters
- `namespace`: The QuickSight namespace that you're deleting the customizations from.
"""
delete_account_customization(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/customizations"; aws_config=aws_config)
delete_account_customization(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/customizations", args; aws_config=aws_config)

"""
    DeleteAnalysis()

Deletes an analysis from Amazon QuickSight. You can optionally include a recovery window during which you can restore the analysis. If you don't specify a recovery window value, the operation defaults to 30 days. QuickSight attaches a DeletionTime stamp to the response that specifies the end of the recovery window. At the end of the recovery window, QuickSight deletes the analysis permanently. At any time before recovery window ends, you can use the RestoreAnalysis API operation to remove the DeletionTime stamp and cancel the deletion of the analysis. The analysis remains visible in the API until it's deleted, so you can describe it but you can't make a template from it. An analysis that's scheduled for deletion isn't accessible in the QuickSight console. To access it in the console, restore it. Deleting an analysis doesn't delete the dashboards that you publish from it.

# Required Parameters
- `AnalysisId`: The ID of the analysis that you're deleting.
- `AwsAccountId`: The ID of the AWS account where you want to delete an analysis.

# Optional Parameters
- `force-delete-without-recovery`: This option defaults to the value NoForceDeleteWithoutRecovery. To immediately delete the analysis, add the ForceDeleteWithoutRecovery option. You can't restore an analysis after it's deleted. 
- `recovery-window-in-days`: A value that specifies the number of days that QuickSight waits before it deletes the analysis. You can't use this parameter with the ForceDeleteWithoutRecovery option in the same API call. The default value is 30.
"""
delete_analysis(AnalysisId, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)"; aws_config=aws_config)
delete_analysis(AnalysisId, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)", args; aws_config=aws_config)

"""
    DeleteDashboard()

Deletes a dashboard.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard that you're deleting.
- `DashboardId`: The ID for the dashboard.

# Optional Parameters
- `version-number`: The version number of the dashboard. If the version number property is provided, only the specified version of the dashboard is deleted.
"""
delete_dashboard(AwsAccountId, DashboardId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)"; aws_config=aws_config)
delete_dashboard(AwsAccountId, DashboardId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)", args; aws_config=aws_config)

"""
    DeleteDataSet()

Deletes a dataset.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.

"""
delete_data_set(AwsAccountId, DataSetId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)"; aws_config=aws_config)
delete_data_set(AwsAccountId, DataSetId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)", args; aws_config=aws_config)

"""
    DeleteDataSource()

Deletes the data source permanently. This operation breaks all the datasets that reference the deleted data source.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSourceId`: The ID of the data source. This ID is unique per AWS Region for each AWS account.

"""
delete_data_source(AwsAccountId, DataSourceId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)"; aws_config=aws_config)
delete_data_source(AwsAccountId, DataSourceId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)", args; aws_config=aws_config)

"""
    DeleteGroup()

Removes a user group from Amazon QuickSight. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: The name of the group that you want to delete.
- `Namespace`: The namespace. Currently, you should set this to default.

"""
delete_group(AwsAccountId, GroupName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)"; aws_config=aws_config)
delete_group(AwsAccountId, GroupName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)", args; aws_config=aws_config)

"""
    DeleteGroupMembership()

Removes a user from a group so that the user is no longer a member of the group.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: The name of the group that you want to delete the user from.
- `MemberName`: The name of the user that you want to delete from the group membership.
- `Namespace`: The namespace. Currently, you should set this to default.

"""
delete_group_membership(AwsAccountId, GroupName, MemberName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)/members/$(MemberName)"; aws_config=aws_config)
delete_group_membership(AwsAccountId, GroupName, MemberName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)/members/$(MemberName)", args; aws_config=aws_config)

"""
    DeleteIAMPolicyAssignment()

Deletes an existing IAM policy assignment.

# Required Parameters
- `AssignmentName`: The name of the assignment. 
- `AwsAccountId`: The AWS account ID where you want to delete the IAM policy assignment.
- `Namespace`: The namespace that contains the assignment.

"""
delete_iampolicy_assignment(AssignmentName, AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespace/$(Namespace)/iam-policy-assignments/$(AssignmentName)"; aws_config=aws_config)
delete_iampolicy_assignment(AssignmentName, AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespace/$(Namespace)/iam-policy-assignments/$(AssignmentName)", args; aws_config=aws_config)

"""
    DeleteNamespace()

Deletes a namespace and the users and groups that are associated with the namespace. This is an asynchronous process. Assets including dashboards, analyses, datasets and data sources are not deleted. To delete these assets, you use the API operations for the relevant asset. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that you want to delete the QuickSight namespace from.
- `Namespace`: The namespace that you want to delete.

"""
delete_namespace(AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)"; aws_config=aws_config)
delete_namespace(AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)", args; aws_config=aws_config)

"""
    DeleteTemplate()

Deletes a template.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the template that you're deleting.
- `TemplateId`: An ID for the template you want to delete.

# Optional Parameters
- `version-number`: Specifies the version of the template that you want to delete. If you don't provide a version number, DeleteTemplate deletes all versions of the template. 
"""
delete_template(AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/templates/$(TemplateId)"; aws_config=aws_config)
delete_template(AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/templates/$(TemplateId)", args; aws_config=aws_config)

"""
    DeleteTemplateAlias()

Deletes the item that the specified template alias points to. If you provide a specific alias, you delete the version of the template that the alias points to.

# Required Parameters
- `AliasName`: The name for the template alias. To delete a specific alias, you delete the version that the alias points to. You can specify the alias name, or specify the latest version of the template by providing the keyword LATEST in the AliasName parameter. 
- `AwsAccountId`: The ID of the AWS account that contains the item to delete.
- `TemplateId`: The ID for the template that the specified alias is for.

"""
delete_template_alias(AliasName, AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)"; aws_config=aws_config)
delete_template_alias(AliasName, AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)", args; aws_config=aws_config)

"""
    DeleteTheme()

Deletes a theme.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the theme that you're deleting.
- `ThemeId`: An ID for the theme that you want to delete.

# Optional Parameters
- `version-number`: The version of the theme that you want to delete.   Note: If you don't provide a version number, you're using this call to DeleteTheme to delete all versions of the theme.
"""
delete_theme(AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/themes/$(ThemeId)"; aws_config=aws_config)
delete_theme(AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/themes/$(ThemeId)", args; aws_config=aws_config)

"""
    DeleteThemeAlias()

Deletes the version of the theme that the specified theme alias points to. If you provide a specific alias, you delete the version of the theme that the alias points to.

# Required Parameters
- `AliasName`: The unique name for the theme alias to delete.
- `AwsAccountId`: The ID of the AWS account that contains the theme alias to delete.
- `ThemeId`: The ID for the theme that the specified alias is for.

"""
delete_theme_alias(AliasName, AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)"; aws_config=aws_config)
delete_theme_alias(AliasName, AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)", args; aws_config=aws_config)

"""
    DeleteUser()

Deletes the Amazon QuickSight user that is associated with the identity of the AWS Identity and Access Management (IAM) user or role that's making the call. The IAM user isn't deleted as a result of this call. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Namespace`: The namespace. Currently, you should set this to default.
- `UserName`: The name of the user that you want to delete.

"""
delete_user(AwsAccountId, Namespace, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)"; aws_config=aws_config)
delete_user(AwsAccountId, Namespace, UserName, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)", args; aws_config=aws_config)

"""
    DeleteUserByPrincipalId()

Deletes a user identified by its principal ID. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Namespace`: The namespace. Currently, you should set this to default.
- `PrincipalId`: The principal ID of the user.

"""
delete_user_by_principal_id(AwsAccountId, Namespace, PrincipalId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/user-principals/$(PrincipalId)"; aws_config=aws_config)
delete_user_by_principal_id(AwsAccountId, Namespace, PrincipalId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/user-principals/$(PrincipalId)", args; aws_config=aws_config)

"""
    DescribeAccountCustomization()

Describes the customizations associated with the provided AWS account and Amazon QuickSight namespace in an AWS Region. The QuickSight console evaluates which customizations to apply by running this API operation with the Resolved flag included.  To determine what customizations display when you run this command, it can help to visualize the relationship of the entities involved.     AWS Account - The AWS account exists at the top of the hierarchy. It has the potential to use all of the AWS Regions and AWS Services. When you subscribe to QuickSight, you choose one AWS Region to use as your home Region. That's where your free SPICE capacity is located. You can use QuickSight in any supported AWS Region.     AWS Region - In each AWS Region where you sign in to QuickSight at least once, QuickSight acts as a separate instance of the same service. If you have a user directory, it resides in us-east-1, which is the US East (N. Virginia). Generally speaking, these users have access to QuickSight in any AWS Region, unless they are constrained to a namespace.  To run the command in a different AWS Region, you change your Region settings. If you're using the AWS CLI, you can use one of the following options:   Use command line options.    Use named profiles.    Run aws configure to change your default AWS Region. Use Enter to key the same settings for your keys. For more information, see Configuring the AWS CLI.      Namespace - A QuickSight namespace is a partition that contains users and assets (data sources, datasets, dashboards, and so on). To access assets that are in a specific namespace, users and groups must also be part of the same namespace. People who share a namespace are completely isolated from users and assets in other namespaces, even if they are in the same AWS account and AWS Region.    Applied customizations - Within an AWS Region, a set of QuickSight customizations can apply to an AWS account or to a namespace. Settings that you apply to a namespace override settings that you apply to an AWS account. All settings are isolated to a single AWS Region. To apply them in other AWS Regions, run the CreateAccountCustomization command in each AWS Region where you want to apply the same customizations.   

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that you want to describe QuickSight customizations for.

# Optional Parameters
- `namespace`: The QuickSight namespace that you want to describe QuickSight customizations for.
- `resolved`: The Resolved flag works with the other parameters to determine which view of QuickSight customizations is returned. You can add this flag to your command to use the same view that QuickSight uses to identify which customizations to apply to the console. Omit this flag, or set it to no-resolved, to reveal customizations that are configured at different levels. 
"""
describe_account_customization(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/customizations"; aws_config=aws_config)
describe_account_customization(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/customizations", args; aws_config=aws_config)

"""
    DescribeAccountSettings()

Describes the settings that were used when your QuickSight subscription was first created in this AWS account.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that contains the settings that you want to list.

"""
describe_account_settings(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/settings"; aws_config=aws_config)
describe_account_settings(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/settings", args; aws_config=aws_config)

"""
    DescribeAnalysis()

Provides a summary of the metadata for an analysis.

# Required Parameters
- `AnalysisId`: The ID of the analysis that you're describing. The ID is part of the URL of the analysis.
- `AwsAccountId`: The ID of the AWS account that contains the analysis. You must be using the AWS account that the analysis is in.

"""
describe_analysis(AnalysisId, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)"; aws_config=aws_config)
describe_analysis(AnalysisId, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)", args; aws_config=aws_config)

"""
    DescribeAnalysisPermissions()

Provides the read and write permissions for an analysis.

# Required Parameters
- `AnalysisId`: The ID of the analysis whose permissions you're describing. The ID is part of the analysis URL.
- `AwsAccountId`: The ID of the AWS account that contains the analysis whose permissions you're describing. You must be using the AWS account that the analysis is in.

"""
describe_analysis_permissions(AnalysisId, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)/permissions"; aws_config=aws_config)
describe_analysis_permissions(AnalysisId, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)/permissions", args; aws_config=aws_config)

"""
    DescribeDashboard()

Provides a summary for a dashboard.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard that you're describing.
- `DashboardId`: The ID for the dashboard.

# Optional Parameters
- `alias-name`: The alias name.
- `version-number`: The version number for the dashboard. If a version number isn't passed, the latest published dashboard version is described. 
"""
describe_dashboard(AwsAccountId, DashboardId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)"; aws_config=aws_config)
describe_dashboard(AwsAccountId, DashboardId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)", args; aws_config=aws_config)

"""
    DescribeDashboardPermissions()

Describes read and write permissions for a dashboard.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard that you're describing permissions for.
- `DashboardId`: The ID for the dashboard, also added to the IAM policy.

"""
describe_dashboard_permissions(AwsAccountId, DashboardId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/permissions"; aws_config=aws_config)
describe_dashboard_permissions(AwsAccountId, DashboardId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/permissions", args; aws_config=aws_config)

"""
    DescribeDataSet()

Describes a dataset. 

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.

"""
describe_data_set(AwsAccountId, DataSetId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)"; aws_config=aws_config)
describe_data_set(AwsAccountId, DataSetId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)", args; aws_config=aws_config)

"""
    DescribeDataSetPermissions()

Describes the permissions on a dataset. The permissions resource is arn:aws:quicksight:region:aws-account-id:dataset/data-set-id.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.

"""
describe_data_set_permissions(AwsAccountId, DataSetId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/permissions"; aws_config=aws_config)
describe_data_set_permissions(AwsAccountId, DataSetId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/permissions", args; aws_config=aws_config)

"""
    DescribeDataSource()

Describes a data source.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSourceId`: The ID of the data source. This ID is unique per AWS Region for each AWS account.

"""
describe_data_source(AwsAccountId, DataSourceId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)"; aws_config=aws_config)
describe_data_source(AwsAccountId, DataSourceId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)", args; aws_config=aws_config)

"""
    DescribeDataSourcePermissions()

Describes the resource permissions for a data source.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSourceId`: The ID of the data source. This ID is unique per AWS Region for each AWS account.

"""
describe_data_source_permissions(AwsAccountId, DataSourceId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)/permissions"; aws_config=aws_config)
describe_data_source_permissions(AwsAccountId, DataSourceId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)/permissions", args; aws_config=aws_config)

"""
    DescribeGroup()

Returns an Amazon QuickSight group's description and Amazon Resource Name (ARN). 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: The name of the group that you want to describe.
- `Namespace`: The namespace. Currently, you should set this to default.

"""
describe_group(AwsAccountId, GroupName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)"; aws_config=aws_config)
describe_group(AwsAccountId, GroupName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)", args; aws_config=aws_config)

"""
    DescribeIAMPolicyAssignment()

Describes an existing IAM policy assignment, as specified by the assignment name.

# Required Parameters
- `AssignmentName`: The name of the assignment, also called a rule.
- `AwsAccountId`: The ID of the AWS account that contains the assignment that you want to describe.
- `Namespace`: The namespace that contains the assignment.

"""
describe_iampolicy_assignment(AssignmentName, AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments/$(AssignmentName)"; aws_config=aws_config)
describe_iampolicy_assignment(AssignmentName, AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments/$(AssignmentName)", args; aws_config=aws_config)

"""
    DescribeIngestion()

Describes a SPICE ingestion.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID of the dataset used in the ingestion.
- `IngestionId`: An ID for the ingestion.

"""
describe_ingestion(AwsAccountId, DataSetId, IngestionId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions/$(IngestionId)"; aws_config=aws_config)
describe_ingestion(AwsAccountId, DataSetId, IngestionId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions/$(IngestionId)", args; aws_config=aws_config)

"""
    DescribeNamespace()

Describes the current namespace.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that contains the QuickSight namespace that you want to describe.
- `Namespace`: The namespace that you want to describe.

"""
describe_namespace(AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)"; aws_config=aws_config)
describe_namespace(AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)", args; aws_config=aws_config)

"""
    DescribeTemplate()

Describes a template's metadata.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the template that you're describing.
- `TemplateId`: The ID for the template.

# Optional Parameters
- `alias-name`: The alias of the template that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the template by providing the keyword LATEST in the AliasName parameter. The keyword PUBLISHED doesn't apply to templates.
- `version-number`: (Optional) The number for the version to describe. If a VersionNumber parameter value isn't provided, the latest version of the template is described.
"""
describe_template(AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)"; aws_config=aws_config)
describe_template(AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)", args; aws_config=aws_config)

"""
    DescribeTemplateAlias()

Describes the template alias for a template.

# Required Parameters
- `AliasName`: The name of the template alias that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the template by providing the keyword LATEST in the AliasName parameter. The keyword PUBLISHED doesn't apply to templates.
- `AwsAccountId`: The ID of the AWS account that contains the template alias that you're describing.
- `TemplateId`: The ID for the template.

"""
describe_template_alias(AliasName, AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)"; aws_config=aws_config)
describe_template_alias(AliasName, AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)", args; aws_config=aws_config)

"""
    DescribeTemplatePermissions()

Describes read and write permissions on a template.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the template that you're describing.
- `TemplateId`: The ID for the template.

"""
describe_template_permissions(AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/permissions"; aws_config=aws_config)
describe_template_permissions(AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/permissions", args; aws_config=aws_config)

"""
    DescribeTheme()

Describes a theme.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the theme that you're describing.
- `ThemeId`: The ID for the theme.

# Optional Parameters
- `alias-name`: The alias of the theme that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the theme by providing the keyword LATEST in the AliasName parameter. The keyword PUBLISHED doesn't apply to themes.
- `version-number`: The version number for the version to describe. If a VersionNumber parameter value isn't provided, the latest version of the theme is described.
"""
describe_theme(AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)"; aws_config=aws_config)
describe_theme(AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)", args; aws_config=aws_config)

"""
    DescribeThemeAlias()

Describes the alias for a theme.

# Required Parameters
- `AliasName`: The name of the theme alias that you want to describe.
- `AwsAccountId`: The ID of the AWS account that contains the theme alias that you're describing.
- `ThemeId`: The ID for the theme.

"""
describe_theme_alias(AliasName, AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)"; aws_config=aws_config)
describe_theme_alias(AliasName, AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)", args; aws_config=aws_config)

"""
    DescribeThemePermissions()

Describes the read and write permissions for a theme.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the theme that you're describing.
- `ThemeId`: The ID for the theme that you want to describe permissions for.

"""
describe_theme_permissions(AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/permissions"; aws_config=aws_config)
describe_theme_permissions(AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/permissions", args; aws_config=aws_config)

"""
    DescribeUser()

Returns information about a user, given the user name. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Namespace`: The namespace. Currently, you should set this to default.
- `UserName`: The name of the user that you want to describe.

"""
describe_user(AwsAccountId, Namespace, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)"; aws_config=aws_config)
describe_user(AwsAccountId, Namespace, UserName, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)", args; aws_config=aws_config)

"""
    GetDashboardEmbedUrl()

Generates a session URL and authorization code that you can use to embed an Amazon QuickSight read-only dashboard in your web server code. Before you use this command, make sure that you have configured the dashboards and permissions.  Currently, you can use GetDashboardEmbedURL only from the server, not from the user's browser. The following rules apply to the combination of URL and authorization code:   They must be used together.   They can be used one time only.   They are valid for 5 minutes after you run this command.   The resulting user session is valid for 10 hours.   For more information, see Embedded Analytics in the Amazon QuickSight User Guide.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that contains the dashboard that you're embedding.
- `DashboardId`: The ID for the dashboard, also added to the AWS Identity and Access Management (IAM) policy.
- `creds-type`: The authentication method that the user uses to sign in.

# Optional Parameters
- `additional-dashboard-ids`: A list of one or more dashboard IDs that you want to add to a session that includes anonymous users. The IdentityType parameter must be set to ANONYMOUS for this to work, because other identity types authenticate as QuickSight or IAM users. For example, if you set \"--dashboard-id dash_id1 --dashboard-id dash_id2 dash_id3 identity-type ANONYMOUS\", the session can access all three dashboards. 
- `namespace`: The QuickSight namespace that contains the dashboard IDs in this request. If you're not using a custom namespace, set this to \"default\".
- `reset-disabled`: Remove the reset button on the embedded dashboard. The default is FALSE, which enables the reset button.
- `session-lifetime`: How many minutes the session is valid. The session lifetime must be 15-600 minutes.
- `state-persistence-enabled`: Adds persistence of state for the user session in an embedded dashboard. Persistence applies to the sheet and the parameter settings. These are control settings that the dashboard subscriber (QuickSight reader) chooses while viewing the dashboard. If this is set to TRUE, the settings are the same when the subscriber reopens the same dashboard URL. The state is stored in QuickSight, not in a browser cookie. If this is set to FALSE, the state of the user session is not persisted. The default is FALSE.
- `undo-redo-disabled`: Remove the undo/redo button on the embedded dashboard. The default is FALSE, which enables the undo/redo button.
- `user-arn`: The Amazon QuickSight user's Amazon Resource Name (ARN), for use with QUICKSIGHT identity type. You can use this for any Amazon QuickSight users in your account (readers, authors, or admins) authenticated as one of the following:   Active Directory (AD) users or group members   Invited nonfederated users   IAM users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation.   Omit this parameter for users in the third group – IAM users and IAM role-based sessions.
"""
get_dashboard_embed_url(AwsAccountId, DashboardId, creds_type; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/embed-url", Dict{String, Any}("creds-type"=>creds_type); aws_config=aws_config)
get_dashboard_embed_url(AwsAccountId, DashboardId, creds_type, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/embed-url", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("creds-type"=>creds_type), args)); aws_config=aws_config)

"""
    GetSessionEmbedUrl()

Generates a session URL and authorization code that you can use to embed the Amazon QuickSight console in your web server code. Use GetSessionEmbedUrl where you want to provide an authoring portal that allows users to create data sources, datasets, analyses, and dashboards. The users who access an embedded QuickSight console need belong to the author or admin security cohort. If you want to restrict permissions to some of these features, add a custom permissions profile to the user with the  UpdateUser  API operation. Use  RegisterUser  API operation to add a new user with a custom permission profile attached. For more information, see the following sections in the Amazon QuickSight User Guide:    Embedding the Amazon QuickSight Console     Customizing Access to the Amazon QuickSight Console   

# Required Parameters
- `AwsAccountId`: The ID for the AWS account associated with your QuickSight subscription.

# Optional Parameters
- `entry-point`: The URL you use to access the embedded session. The entry point URL is constrained to the following paths:    /start     /start/analyses     /start/dashboards     /start/favorites     /dashboards/DashboardId  - where DashboardId is the actual ID key from the QuickSight console URL of the dashboard    /analyses/AnalysisId  - where AnalysisId is the actual ID key from the QuickSight console URL of the analysis  
- `session-lifetime`: How many minutes the session is valid. The session lifetime must be 15-600 minutes.
- `user-arn`: The Amazon QuickSight user's Amazon Resource Name (ARN), for use with QUICKSIGHT identity type. You can use this for any type of Amazon QuickSight users in your account (readers, authors, or admins). They need to be authenticated as one of the following:   Active Directory (AD) users or group members   Invited nonfederated users   AWS Identity and Access Management (IAM) users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation   Omit this parameter for users in the third group, IAM users and IAM role-based sessions.
"""
get_session_embed_url(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/session-embed-url"; aws_config=aws_config)
get_session_embed_url(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/session-embed-url", args; aws_config=aws_config)

"""
    ListAnalyses()

Lists Amazon QuickSight analyses that exist in the specified AWS account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the analyses.

# Optional Parameters
- `max-results`: The maximum number of results to return.
- `next-token`: A pagination token that can be used in a subsequent request.
"""
list_analyses(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/analyses"; aws_config=aws_config)
list_analyses(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/analyses", args; aws_config=aws_config)

"""
    ListDashboardVersions()

Lists all the versions of the dashboards in the QuickSight subscription.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard that you're listing versions for.
- `DashboardId`: The ID for the dashboard.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_dashboard_versions(AwsAccountId, DashboardId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/versions"; aws_config=aws_config)
list_dashboard_versions(AwsAccountId, DashboardId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/versions", args; aws_config=aws_config)

"""
    ListDashboards()

Lists dashboards in an AWS account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboards that you're listing.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_dashboards(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards"; aws_config=aws_config)
list_dashboards(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/dashboards", args; aws_config=aws_config)

"""
    ListDataSets()

Lists all of the datasets belonging to the current AWS account in an AWS Region. The permissions resource is arn:aws:quicksight:region:aws-account-id:dataset/*.

# Required Parameters
- `AwsAccountId`: The AWS account ID.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_data_sets(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets"; aws_config=aws_config)
list_data_sets(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets", args; aws_config=aws_config)

"""
    ListDataSources()

Lists data sources in current AWS Region that belong to this AWS account.

# Required Parameters
- `AwsAccountId`: The AWS account ID.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_data_sources(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sources"; aws_config=aws_config)
list_data_sources(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sources", args; aws_config=aws_config)

"""
    ListGroupMemberships()

Lists member users in a group.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: The name of the group that you want to see a membership list of.
- `Namespace`: The namespace. Currently, you should set this to default.

# Optional Parameters
- `max-results`: The maximum number of results to return from this request.
- `next-token`: A pagination token that can be used in a subsequent request.
"""
list_group_memberships(AwsAccountId, GroupName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)/members"; aws_config=aws_config)
list_group_memberships(AwsAccountId, GroupName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)/members", args; aws_config=aws_config)

"""
    ListGroups()

Lists all user groups in Amazon QuickSight. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Namespace`: The namespace. Currently, you should set this to default.

# Optional Parameters
- `max-results`: The maximum number of results to return.
- `next-token`: A pagination token that can be used in a subsequent request.
"""
list_groups(AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups"; aws_config=aws_config)
list_groups(AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups", args; aws_config=aws_config)

"""
    ListIAMPolicyAssignments()

Lists IAM policy assignments in the current Amazon QuickSight account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains these IAM policy assignments.
- `Namespace`: The namespace for the assignments.

# Optional Parameters
- `AssignmentStatus`: The status of the assignments.
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_iampolicy_assignments(AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments"; aws_config=aws_config)
list_iampolicy_assignments(AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments", args; aws_config=aws_config)

"""
    ListIAMPolicyAssignmentsForUser()

Lists all the IAM policy assignments, including the Amazon Resource Names (ARNs) for the IAM policies assigned to the specified user and group or groups that the user belongs to.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the assignments.
- `Namespace`: The namespace of the assignment.
- `UserName`: The name of the user.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_iampolicy_assignments_for_user(AwsAccountId, Namespace, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)/iam-policy-assignments"; aws_config=aws_config)
list_iampolicy_assignments_for_user(AwsAccountId, Namespace, UserName, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)/iam-policy-assignments", args; aws_config=aws_config)

"""
    ListIngestions()

Lists the history of SPICE ingestions for a dataset.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID of the dataset used in the ingestion.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_ingestions(AwsAccountId, DataSetId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions"; aws_config=aws_config)
list_ingestions(AwsAccountId, DataSetId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/ingestions", args; aws_config=aws_config)

"""
    ListNamespaces()

Lists the namespaces for the specified AWS account.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that contains the QuickSight namespaces that you want to list.

# Optional Parameters
- `max-results`: The maximum number of results to return.
- `next-token`: A pagination token that can be used in a subsequent request.
"""
list_namespaces(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces"; aws_config=aws_config)
list_namespaces(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces", args; aws_config=aws_config)

"""
    ListTagsForResource()

Lists the tags assigned to a resource.

# Required Parameters
- `ResourceArn`: The Amazon Resource Name (ARN) of the resource that you want a list of tags for.

"""
list_tags_for_resource(ResourceArn; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/resources/$(ResourceArn)/tags"; aws_config=aws_config)
list_tags_for_resource(ResourceArn, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/resources/$(ResourceArn)/tags", args; aws_config=aws_config)

"""
    ListTemplateAliases()

Lists all the aliases of a template.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the template aliases that you're listing.
- `TemplateId`: The ID for the template.

# Optional Parameters
- `max-result`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_template_aliases(AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases"; aws_config=aws_config)
list_template_aliases(AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases", args; aws_config=aws_config)

"""
    ListTemplateVersions()

Lists all the versions of the templates in the current Amazon QuickSight account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the templates that you're listing.
- `TemplateId`: The ID for the template.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_template_versions(AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/versions"; aws_config=aws_config)
list_template_versions(AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/versions", args; aws_config=aws_config)

"""
    ListTemplates()

Lists all the templates in the current Amazon QuickSight account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the templates that you're listing.

# Optional Parameters
- `max-result`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_templates(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates"; aws_config=aws_config)
list_templates(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/templates", args; aws_config=aws_config)

"""
    ListThemeAliases()

Lists all the aliases of a theme.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the theme aliases that you're listing.
- `ThemeId`: The ID for the theme.

# Optional Parameters
- `max-result`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_theme_aliases(AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases"; aws_config=aws_config)
list_theme_aliases(AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases", args; aws_config=aws_config)

"""
    ListThemeVersions()

Lists all the versions of the themes in the current AWS account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the themes that you're listing.
- `ThemeId`: The ID for the theme.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
"""
list_theme_versions(AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/versions"; aws_config=aws_config)
list_theme_versions(AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/versions", args; aws_config=aws_config)

"""
    ListThemes()

Lists all the themes in the current AWS account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the themes that you're listing.

# Optional Parameters
- `max-results`: The maximum number of results to be returned per request.
- `next-token`: The token for the next set of results, or null if there are no more results.
- `type`: The type of themes that you want to list. Valid options include the following:    ALL (default)- Display all existing themes.    CUSTOM - Display only the themes created by people using Amazon QuickSight.    QUICKSIGHT - Display only the starting themes defined by QuickSight.  
"""
list_themes(AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes"; aws_config=aws_config)
list_themes(AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/themes", args; aws_config=aws_config)

"""
    ListUserGroups()

Lists the Amazon QuickSight groups that an Amazon QuickSight user is a member of.

# Required Parameters
- `AwsAccountId`: The AWS account ID that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Namespace`: The namespace. Currently, you should set this to default.
- `UserName`: The Amazon QuickSight user name that you want to list group memberships for.

# Optional Parameters
- `max-results`: The maximum number of results to return from this request.
- `next-token`: A pagination token that can be used in a subsequent request.
"""
list_user_groups(AwsAccountId, Namespace, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)/groups"; aws_config=aws_config)
list_user_groups(AwsAccountId, Namespace, UserName, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)/groups", args; aws_config=aws_config)

"""
    ListUsers()

Returns a list of all of the Amazon QuickSight users belonging to this account. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Namespace`: The namespace. Currently, you should set this to default.

# Optional Parameters
- `max-results`: The maximum number of results to return from this request.
- `next-token`: A pagination token that can be used in a subsequent request.
"""
list_users(AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users"; aws_config=aws_config)
list_users(AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("GET", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users", args; aws_config=aws_config)

"""
    RegisterUser()

Creates an Amazon QuickSight user, whose identity is associated with the AWS Identity and Access Management (IAM) identity or role specified in the request. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Email`: The email address of the user that you want to register.
- `IdentityType`: Amazon QuickSight supports several ways of managing the identity of users. This parameter accepts two values:    IAM: A user whose identity maps to an existing IAM user or role.     QUICKSIGHT: A user whose identity is owned and managed internally by Amazon QuickSight.   
- `Namespace`: The namespace. Currently, you should set this to default.
- `UserRole`: The Amazon QuickSight role for the user. The user role can be one of the following:    READER: A user who has read-only access to dashboards.    AUTHOR: A user who can create data sources, datasets, analyses, and dashboards.    ADMIN: A user who is an author, who can also manage Amazon QuickSight settings.    RESTRICTED_READER: This role isn't currently available for use.    RESTRICTED_AUTHOR: This role isn't currently available for use.  

# Optional Parameters
- `CustomPermissionsName`: (Enterprise edition only) The name of the custom permissions profile that you want to assign to this user. Customized permissions allows you to control a user's access by restricting access the following operations:   Create and update data sources   Create and update datasets   Create and update email reports   Subscribe to email reports   To add custom permissions to an existing user, use  UpdateUser  instead. A set of custom permissions includes any combination of these restrictions. Currently, you need to create the profile names for custom permission sets by using the QuickSight console. Then, you use the RegisterUser API operation to assign the named set of permissions to a QuickSight user.  QuickSight custom permissions are applied through IAM policies. Therefore, they override the permissions typically granted by assigning QuickSight users to one of the default security cohorts in QuickSight (admin, author, reader). This feature is available only to QuickSight Enterprise edition subscriptions that use SAML 2.0-Based Federation for Single Sign-On (SSO).
- `IamArn`: The ARN of the IAM user or role that you are registering with Amazon QuickSight. 
- `SessionName`: You need to use this parameter only when you register one or more users using an assumed IAM role. You don't need to provide the session name for other scenarios, for example when you are registering an IAM user or an Amazon QuickSight user. You can register multiple users using the same IAM role if each user has a different session name. For more information on assuming IAM roles, see  assume-role  in the AWS CLI Reference. 
- `UserName`: The Amazon QuickSight user name that you want to create for the user you are registering.
"""
register_user(AwsAccountId, Email, IdentityType, Namespace, UserRole; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users", Dict{String, Any}("Email"=>Email, "IdentityType"=>IdentityType, "UserRole"=>UserRole); aws_config=aws_config)
register_user(AwsAccountId, Email, IdentityType, Namespace, UserRole, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Email"=>Email, "IdentityType"=>IdentityType, "UserRole"=>UserRole), args)); aws_config=aws_config)

"""
    RestoreAnalysis()

Restores an analysis.

# Required Parameters
- `AnalysisId`: The ID of the analysis that you're restoring.
- `AwsAccountId`: The ID of the AWS account that contains the analysis.

"""
restore_analysis(AnalysisId, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/restore/analyses/$(AnalysisId)"; aws_config=aws_config)
restore_analysis(AnalysisId, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/restore/analyses/$(AnalysisId)", args; aws_config=aws_config)

"""
    SearchAnalyses()

Searches for analyses that belong to the user specified in the filter.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the analyses that you're searching for.
- `Filters`: The structure for the search filters that you want to apply to your search. 

# Optional Parameters
- `MaxResults`: The maximum number of results to return.
- `NextToken`: A pagination token that can be used in a subsequent request.
"""
search_analyses(AwsAccountId, Filters; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/search/analyses", Dict{String, Any}("Filters"=>Filters); aws_config=aws_config)
search_analyses(AwsAccountId, Filters, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/search/analyses", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Filters"=>Filters), args)); aws_config=aws_config)

"""
    SearchDashboards()

Searches for dashboards that belong to a user. 

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the user whose dashboards you're searching for. 
- `Filters`: The filters to apply to the search. Currently, you can search only by user name, for example, \"Filters\": [ { \"Name\": \"QUICKSIGHT_USER\", \"Operator\": \"StringEquals\", \"Value\": \"arn:aws:quicksight:us-east-1:1:user/default/UserName1\" } ] 

# Optional Parameters
- `MaxResults`: The maximum number of results to be returned per request.
- `NextToken`: The token for the next set of results, or null if there are no more results.
"""
search_dashboards(AwsAccountId, Filters; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/search/dashboards", Dict{String, Any}("Filters"=>Filters); aws_config=aws_config)
search_dashboards(AwsAccountId, Filters, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/search/dashboards", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Filters"=>Filters), args)); aws_config=aws_config)

"""
    TagResource()

Assigns one or more tags (key-value pairs) to the specified QuickSight resource.  Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only resources with certain tag values. You can use the TagResource operation with a resource that already has tags. If you specify a new tag key for the resource, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag. You can associate as many as 50 tags with a resource. QuickSight supports tagging on data set, data source, dashboard, and template.  Tagging for QuickSight works in a similar way to tagging for other AWS services, except for the following:   You can't use tags to track AWS costs for QuickSight. This restriction is because QuickSight costs are based on users and SPICE capacity, which aren't taggable resources.   QuickSight doesn't currently support the Tag Editor for AWS Resource Groups.  

# Required Parameters
- `ResourceArn`: The Amazon Resource Name (ARN) of the resource that you want to tag.
- `Tags`: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

"""
tag_resource(ResourceArn, Tags; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/resources/$(ResourceArn)/tags", Dict{String, Any}("Tags"=>Tags); aws_config=aws_config)
tag_resource(ResourceArn, Tags, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/resources/$(ResourceArn)/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Tags"=>Tags), args)); aws_config=aws_config)

"""
    UntagResource()

Removes a tag or tags from a resource.

# Required Parameters
- `ResourceArn`: The Amazon Resource Name (ARN) of the resource that you want to untag.
- `keys`: The keys of the key-value pairs for the resource tag or tags assigned to the resource.

"""
untag_resource(ResourceArn, keys; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/resources/$(ResourceArn)/tags", Dict{String, Any}("keys"=>keys); aws_config=aws_config)
untag_resource(ResourceArn, keys, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("DELETE", "/resources/$(ResourceArn)/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("keys"=>keys), args)); aws_config=aws_config)

"""
    UpdateAccountCustomization()

Updates Amazon QuickSight customizations the current AWS Region. Currently, the only customization you can use is a theme. You can use customizations for your AWS account or, if you specify a namespace, for a QuickSight namespace instead. Customizations that apply to a namespace override customizations that apply to an AWS account. To find out which customizations apply, use the DescribeAccountCustomization API operation. 

# Required Parameters
- `AccountCustomization`: The QuickSight customizations you're updating in the current AWS Region. 
- `AwsAccountId`: The ID for the AWS account that you want to update QuickSight customizations for.

# Optional Parameters
- `namespace`: The namespace that you want to update QuickSight customizations for.
"""
update_account_customization(AccountCustomization, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/customizations", Dict{String, Any}("AccountCustomization"=>AccountCustomization); aws_config=aws_config)
update_account_customization(AccountCustomization, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/customizations", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountCustomization"=>AccountCustomization), args)); aws_config=aws_config)

"""
    UpdateAccountSettings()

Updates the Amazon QuickSight settings in your AWS account.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that contains the QuickSight settings that you want to list.
- `DefaultNamespace`: The default namespace for this AWS account. Currently, the default is default. AWS Identity and Access Management (IAM) users that register for the first time with QuickSight provide an email that becomes associated with the default namespace.

# Optional Parameters
- `NotificationEmail`: The email address that you want QuickSight to send notifications to regarding your AWS account or QuickSight subscription.
"""
update_account_settings(AwsAccountId, DefaultNamespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/settings", Dict{String, Any}("DefaultNamespace"=>DefaultNamespace); aws_config=aws_config)
update_account_settings(AwsAccountId, DefaultNamespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/settings", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("DefaultNamespace"=>DefaultNamespace), args)); aws_config=aws_config)

"""
    UpdateAnalysis()

Updates an analysis in Amazon QuickSight

# Required Parameters
- `AnalysisId`: The ID for the analysis that you're updating. This ID displays in the URL of the analysis.
- `AwsAccountId`: The ID of the AWS account that contains the analysis that you're updating.
- `Name`: A descriptive name for the analysis that you're updating. This name displays for the analysis in the QuickSight console.
- `SourceEntity`: A source entity to use for the analysis that you're updating. This metadata structure contains details that describe a source template and one or more datasets.

# Optional Parameters
- `Parameters`: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values. 
- `ThemeArn`: The Amazon Resource Name (ARN) for the theme to apply to the analysis that you're creating. To see the theme in the QuickSight console, make sure that you have access to it.
"""
update_analysis(AnalysisId, AwsAccountId, Name, SourceEntity; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)", Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity); aws_config=aws_config)
update_analysis(AnalysisId, AwsAccountId, Name, SourceEntity, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity), args)); aws_config=aws_config)

"""
    UpdateAnalysisPermissions()

Updates the read and write permissions for an analysis.

# Required Parameters
- `AnalysisId`: The ID of the analysis whose permissions you're updating. The ID is part of the analysis URL.
- `AwsAccountId`: The ID of the AWS account that contains the analysis whose permissions you're updating. You must be using the AWS account that the analysis is in.

# Optional Parameters
- `GrantPermissions`: A structure that describes the permissions to add and the principal to add them to.
- `RevokePermissions`: A structure that describes the permissions to remove and the principal to remove them from.
"""
update_analysis_permissions(AnalysisId, AwsAccountId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)/permissions"; aws_config=aws_config)
update_analysis_permissions(AnalysisId, AwsAccountId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/analyses/$(AnalysisId)/permissions", args; aws_config=aws_config)

"""
    UpdateDashboard()

Updates a dashboard in an AWS account.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard that you're updating.
- `DashboardId`: The ID for the dashboard.
- `Name`: The display name of the dashboard.
- `SourceEntity`: The entity that you are using as a source when you update the dashboard. In SourceEntity, you specify the type of object you're using as source. You can only update a dashboard from a template, so you use a SourceTemplate entity. If you need to update a dashboard from an analysis, first convert the analysis to a template by using the CreateTemplate API operation. For SourceTemplate, specify the Amazon Resource Name (ARN) of the source template. The SourceTemplate ARN can contain any AWS Account and any QuickSight-supported AWS Region.  Use the DataSetReferences entity within SourceTemplate to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. 

# Optional Parameters
- `DashboardPublishOptions`: Options for publishing the dashboard when you create it:    AvailabilityStatus for AdHocFilteringOption - This status can be either ENABLED or DISABLED. When this is set to DISABLED, QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ENABLED by default.     AvailabilityStatus for ExportToCSVOption - This status can be either ENABLED or DISABLED. The visual option to export data to .CSV format isn't enabled when this is set to DISABLED. This option is ENABLED by default.     VisibilityState for SheetControlsOption - This visibility state can be either COLLAPSED or EXPANDED. This option is COLLAPSED by default.   
- `Parameters`: A structure that contains the parameters of the dashboard. These are parameter overrides for a dashboard. A dashboard can have any type of parameters, and some parameters might accept multiple values.
- `ThemeArn`: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that was originally associated with the entity. The theme ARN must exist in the same AWS account where you create the dashboard.
- `VersionDescription`: A description for the first version of the dashboard being created.
"""
update_dashboard(AwsAccountId, DashboardId, Name, SourceEntity; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)", Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity); aws_config=aws_config)
update_dashboard(AwsAccountId, DashboardId, Name, SourceEntity, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name, "SourceEntity"=>SourceEntity), args)); aws_config=aws_config)

"""
    UpdateDashboardPermissions()

Updates read and write permissions on a dashboard.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard whose permissions you're updating.
- `DashboardId`: The ID for the dashboard.

# Optional Parameters
- `GrantPermissions`: The permissions that you want to grant on this resource.
- `RevokePermissions`: The permissions that you want to revoke from this resource.
"""
update_dashboard_permissions(AwsAccountId, DashboardId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/permissions"; aws_config=aws_config)
update_dashboard_permissions(AwsAccountId, DashboardId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/permissions", args; aws_config=aws_config)

"""
    UpdateDashboardPublishedVersion()

Updates the published version of a dashboard.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the dashboard that you're updating.
- `DashboardId`: The ID for the dashboard.
- `VersionNumber`: The version number of the dashboard.

"""
update_dashboard_published_version(AwsAccountId, DashboardId, VersionNumber; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/versions/$(VersionNumber)"; aws_config=aws_config)
update_dashboard_published_version(AwsAccountId, DashboardId, VersionNumber, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/dashboards/$(DashboardId)/versions/$(VersionNumber)", args; aws_config=aws_config)

"""
    UpdateDataSet()

Updates a dataset.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID for the dataset that you want to update. This ID is unique per AWS Region for each AWS account.
- `ImportMode`: Indicates whether you want to import the data into SPICE.
- `Name`: The display name for the dataset.
- `PhysicalTableMap`: Declares the physical tables that are available in the underlying data sources.

# Optional Parameters
- `ColumnGroups`: Groupings of columns that work together in certain QuickSight features. Currently, only geospatial hierarchy is supported.
- `ColumnLevelPermissionRules`: A set of one or more definitions of a  ColumnLevelPermissionRule .
- `LogicalTableMap`: Configures the combination and transformation of the data from the physical tables.
- `RowLevelPermissionDataSet`: The row-level security configuration for the data you want to create.
"""
update_data_set(AwsAccountId, DataSetId, ImportMode, Name, PhysicalTableMap; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)", Dict{String, Any}("ImportMode"=>ImportMode, "Name"=>Name, "PhysicalTableMap"=>PhysicalTableMap); aws_config=aws_config)
update_data_set(AwsAccountId, DataSetId, ImportMode, Name, PhysicalTableMap, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ImportMode"=>ImportMode, "Name"=>Name, "PhysicalTableMap"=>PhysicalTableMap), args)); aws_config=aws_config)

"""
    UpdateDataSetPermissions()

Updates the permissions on a dataset. The permissions resource is arn:aws:quicksight:region:aws-account-id:dataset/data-set-id.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSetId`: The ID for the dataset whose permissions you want to update. This ID is unique per AWS Region for each AWS account.

# Optional Parameters
- `GrantPermissions`: The resource permissions that you want to grant to the dataset.
- `RevokePermissions`: The resource permissions that you want to revoke from the dataset.
"""
update_data_set_permissions(AwsAccountId, DataSetId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/permissions"; aws_config=aws_config)
update_data_set_permissions(AwsAccountId, DataSetId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sets/$(DataSetId)/permissions", args; aws_config=aws_config)

"""
    UpdateDataSource()

Updates a data source.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSourceId`: The ID of the data source. This ID is unique per AWS Region for each AWS account. 
- `Name`: A display name for the data source.

# Optional Parameters
- `Credentials`: The credentials that QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
- `DataSourceParameters`: The parameters that QuickSight uses to connect to your underlying source.
- `SslProperties`: Secure Socket Layer (SSL) properties that apply when QuickSight connects to your underlying source.
- `VpcConnectionProperties`: Use this parameter only when you want QuickSight to use a VPC connection when connecting to your underlying source.
"""
update_data_source(AwsAccountId, DataSourceId, Name; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)", Dict{String, Any}("Name"=>Name); aws_config=aws_config)
update_data_source(AwsAccountId, DataSourceId, Name, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name), args)); aws_config=aws_config)

"""
    UpdateDataSourcePermissions()

Updates the permissions to a data source.

# Required Parameters
- `AwsAccountId`: The AWS account ID.
- `DataSourceId`: The ID of the data source. This ID is unique per AWS Region for each AWS account. 

# Optional Parameters
- `GrantPermissions`: A list of resource permissions that you want to grant on the data source.
- `RevokePermissions`: A list of resource permissions that you want to revoke on the data source.
"""
update_data_source_permissions(AwsAccountId, DataSourceId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)/permissions"; aws_config=aws_config)
update_data_source_permissions(AwsAccountId, DataSourceId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("POST", "/accounts/$(AwsAccountId)/data-sources/$(DataSourceId)/permissions", args; aws_config=aws_config)

"""
    UpdateGroup()

Changes a group description. 

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `GroupName`: The name of the group that you want to update.
- `Namespace`: The namespace. Currently, you should set this to default.

# Optional Parameters
- `Description`: The description for the group that you want to update.
"""
update_group(AwsAccountId, GroupName, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)"; aws_config=aws_config)
update_group(AwsAccountId, GroupName, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/groups/$(GroupName)", args; aws_config=aws_config)

"""
    UpdateIAMPolicyAssignment()

Updates an existing IAM policy assignment. This operation updates only the optional parameter or parameters that are specified in the request. This overwrites all of the users included in Identities. 

# Required Parameters
- `AssignmentName`: The name of the assignment, also called a rule. This name must be unique within an AWS account.
- `AwsAccountId`: The ID of the AWS account that contains the IAM policy assignment. 
- `Namespace`: The namespace of the assignment.

# Optional Parameters
- `AssignmentStatus`: The status of the assignment. Possible values are as follows:    ENABLED - Anything specified in this assignment is used when creating the data source.    DISABLED - This assignment isn't used when creating the data source.    DRAFT - This assignment is an unfinished draft and isn't used when creating the data source.  
- `Identities`: The QuickSight users, groups, or both that you want to assign the policy to.
- `PolicyArn`: The ARN for the IAM policy to apply to the QuickSight users and groups specified in this assignment.
"""
update_iampolicy_assignment(AssignmentName, AwsAccountId, Namespace; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments/$(AssignmentName)"; aws_config=aws_config)
update_iampolicy_assignment(AssignmentName, AwsAccountId, Namespace, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/iam-policy-assignments/$(AssignmentName)", args; aws_config=aws_config)

"""
    UpdateTemplate()

Updates a template from an existing Amazon QuickSight analysis or another template.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the template that you're updating.
- `SourceEntity`: The entity that you are using as a source when you update the template. In SourceEntity, you specify the type of object you're using as source: SourceTemplate for a template or SourceAnalysis for an analysis. Both of these require an Amazon Resource Name (ARN). For SourceTemplate, specify the ARN of the source template. For SourceAnalysis, specify the ARN of the source analysis. The SourceTemplate ARN can contain any AWS Account and any QuickSight-supported AWS Region.  Use the DataSetReferences entity within SourceTemplate or SourceAnalysis to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. 
- `TemplateId`: The ID for the template.

# Optional Parameters
- `Name`: The name for the template.
- `VersionDescription`: A description of the current template version that is being updated. Every time you call UpdateTemplate, you create a new version of the template. Each version of the template maintains a description of the version in the VersionDescription field.
"""
update_template(AwsAccountId, SourceEntity, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/templates/$(TemplateId)", Dict{String, Any}("SourceEntity"=>SourceEntity); aws_config=aws_config)
update_template(AwsAccountId, SourceEntity, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/templates/$(TemplateId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("SourceEntity"=>SourceEntity), args)); aws_config=aws_config)

"""
    UpdateTemplateAlias()

Updates the template alias of a template.

# Required Parameters
- `AliasName`: The alias of the template that you want to update. If you name a specific alias, you update the version that the alias points to. You can specify the latest version of the template by providing the keyword LATEST in the AliasName parameter. The keyword PUBLISHED doesn't apply to templates.
- `AwsAccountId`: The ID of the AWS account that contains the template alias that you're updating.
- `TemplateId`: The ID for the template.
- `TemplateVersionNumber`: The version number of the template.

"""
update_template_alias(AliasName, AwsAccountId, TemplateId, TemplateVersionNumber; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)", Dict{String, Any}("TemplateVersionNumber"=>TemplateVersionNumber); aws_config=aws_config)
update_template_alias(AliasName, AwsAccountId, TemplateId, TemplateVersionNumber, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/aliases/$(AliasName)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("TemplateVersionNumber"=>TemplateVersionNumber), args)); aws_config=aws_config)

"""
    UpdateTemplatePermissions()

Updates the resource permissions for a template.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the template.
- `TemplateId`: The ID for the template.

# Optional Parameters
- `GrantPermissions`: A list of resource permissions to be granted on the template. 
- `RevokePermissions`: A list of resource permissions to be revoked from the template. 
"""
update_template_permissions(AwsAccountId, TemplateId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/permissions"; aws_config=aws_config)
update_template_permissions(AwsAccountId, TemplateId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/templates/$(TemplateId)/permissions", args; aws_config=aws_config)

"""
    UpdateTheme()

Updates a theme.

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the theme that you're updating.
- `BaseThemeId`: The theme ID, defined by Amazon QuickSight, that a custom theme inherits from. All themes initially inherit from a default QuickSight theme.
- `ThemeId`: The ID for the theme.

# Optional Parameters
- `Configuration`: The theme configuration, which contains the theme display properties.
- `Name`: The name for the theme.
- `VersionDescription`: A description of the theme version that you're updating Every time that you call UpdateTheme, you create a new version of the theme. Each version of the theme maintains a description of the version in VersionDescription.
"""
update_theme(AwsAccountId, BaseThemeId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/themes/$(ThemeId)", Dict{String, Any}("BaseThemeId"=>BaseThemeId); aws_config=aws_config)
update_theme(AwsAccountId, BaseThemeId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/themes/$(ThemeId)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("BaseThemeId"=>BaseThemeId), args)); aws_config=aws_config)

"""
    UpdateThemeAlias()

Updates an alias of a theme.

# Required Parameters
- `AliasName`: The name of the theme alias that you want to update.
- `AwsAccountId`: The ID of the AWS account that contains the theme alias that you're updating.
- `ThemeId`: The ID for the theme.
- `ThemeVersionNumber`: The version number of the theme that the alias should reference.

"""
update_theme_alias(AliasName, AwsAccountId, ThemeId, ThemeVersionNumber; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)", Dict{String, Any}("ThemeVersionNumber"=>ThemeVersionNumber); aws_config=aws_config)
update_theme_alias(AliasName, AwsAccountId, ThemeId, ThemeVersionNumber, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/aliases/$(AliasName)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ThemeVersionNumber"=>ThemeVersionNumber), args)); aws_config=aws_config)

"""
    UpdateThemePermissions()

Updates the resource permissions for a theme. Permissions apply to the action to grant or revoke permissions on, for example \"quicksight:DescribeTheme\". Theme permissions apply in groupings. Valid groupings include the following for the three levels of permissions, which are user, owner, or no permissions:    User    \"quicksight:DescribeTheme\"     \"quicksight:DescribeThemeAlias\"     \"quicksight:ListThemeAliases\"     \"quicksight:ListThemeVersions\"      Owner    \"quicksight:DescribeTheme\"     \"quicksight:DescribeThemeAlias\"     \"quicksight:ListThemeAliases\"     \"quicksight:ListThemeVersions\"     \"quicksight:DeleteTheme\"     \"quicksight:UpdateTheme\"     \"quicksight:CreateThemeAlias\"     \"quicksight:DeleteThemeAlias\"     \"quicksight:UpdateThemeAlias\"     \"quicksight:UpdateThemePermissions\"     \"quicksight:DescribeThemePermissions\"      To specify no permissions, omit the permissions list.  

# Required Parameters
- `AwsAccountId`: The ID of the AWS account that contains the theme.
- `ThemeId`: The ID for the theme.

# Optional Parameters
- `GrantPermissions`: A list of resource permissions to be granted for the theme.
- `RevokePermissions`: A list of resource permissions to be revoked from the theme.
"""
update_theme_permissions(AwsAccountId, ThemeId; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/permissions"; aws_config=aws_config)
update_theme_permissions(AwsAccountId, ThemeId, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/themes/$(ThemeId)/permissions", args; aws_config=aws_config)

"""
    UpdateUser()

Updates an Amazon QuickSight user.

# Required Parameters
- `AwsAccountId`: The ID for the AWS account that the user is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
- `Email`: The email address of the user that you want to update.
- `Namespace`: The namespace. Currently, you should set this to default.
- `Role`: The Amazon QuickSight role of the user. The role can be one of the following default security cohorts:    READER: A user who has read-only access to dashboards.    AUTHOR: A user who can create data sources, datasets, analyses, and dashboards.    ADMIN: A user who is an author, who can also manage Amazon QuickSight settings.   The name of the QuickSight role is invisible to the user except for the console screens dealing with permissions.
- `UserName`: The Amazon QuickSight user name that you want to update.

# Optional Parameters
- `CustomPermissionsName`: (Enterprise edition only) The name of the custom permissions profile that you want to assign to this user. Customized permissions allows you to control a user's access by restricting access the following operations:   Create and update data sources   Create and update datasets   Create and update email reports   Subscribe to email reports   A set of custom permissions includes any combination of these restrictions. Currently, you need to create the profile names for custom permission sets by using the QuickSight console. Then, you use the RegisterUser API operation to assign the named set of permissions to a QuickSight user.  QuickSight custom permissions are applied through IAM policies. Therefore, they override the permissions typically granted by assigning QuickSight users to one of the default security cohorts in QuickSight (admin, author, reader). This feature is available only to QuickSight Enterprise edition subscriptions that use SAML 2.0-Based Federation for Single Sign-On (SSO).
- `UnapplyCustomPermissions`: A flag that you use to indicate that you want to remove all custom permissions from this user. Using this parameter resets the user to the state it was in before a custom permissions profile was applied. This parameter defaults to NULL and it doesn't accept any other value.
"""
update_user(AwsAccountId, Email, Namespace, Role, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)", Dict{String, Any}("Email"=>Email, "Role"=>Role); aws_config=aws_config)
update_user(AwsAccountId, Email, Namespace, Role, UserName, args::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = quicksight("PUT", "/accounts/$(AwsAccountId)/namespaces/$(Namespace)/users/$(UserName)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Email"=>Email, "Role"=>Role), args)); aws_config=aws_config)
